@@ -1,3 +1,6 @@
+#ifndef TP_GEN_TP_CLI_CHANNEL_REQUEST_H_INCLUDED
+#define TP_GEN_TP_CLI_CHANNEL_REQUEST_H_INCLUDED
+
 G_BEGIN_DECLS
 
 typedef void (*tp_cli_channel_request_signal_callback_failed) (TpChannelRequest *proxy,
@@ -58,3 +61,5 @@ TpProxyPendingCall *tp_cli_channel_request_call_cancel (TpChannelRequest *proxy,
 
 
 G_END_DECLS
+
+#endif /* defined (TP_GEN_TP_CLI_CHANNEL_REQUEST_H_INCLUDED) */
