@@ -1,3 +1,6 @@
+#ifndef TP_GEN_TP_CLI_MEDIA_STREAM_HANDLER_H_INCLUDED
+#define TP_GEN_TP_CLI_MEDIA_STREAM_HANDLER_H_INCLUDED
+
 G_BEGIN_DECLS
 
 typedef void (*tp_cli_media_stream_handler_signal_callback_add_remote_candidate) (TpMediaStreamHandler *proxy,
@@ -475,3 +478,5 @@ gboolean tp_cli_media_stream_handler_run_supported_header_extensions (TpMediaStr
 
 
 G_END_DECLS
+
+#endif /* defined (TP_GEN_TP_CLI_MEDIA_STREAM_HANDLER_H_INCLUDED) */
