@@ -1428,6 +1428,38 @@ tp_svc_connection_interface_presence_return_from_set_status (DBusGMethodInvocati
 void tp_svc_connection_interface_presence_emit_presence_update (gpointer instance,
     GHashTable *arg_Presence);
 
+typedef struct _TpSvcConnectionInterfaceRenaming TpSvcConnectionInterfaceRenaming;
+
+typedef struct _TpSvcConnectionInterfaceRenamingClass TpSvcConnectionInterfaceRenamingClass;
+
+GType tp_svc_connection_interface_renaming_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_RENAMING \
+  (tp_svc_connection_interface_renaming_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_RENAMING(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_RENAMING, TpSvcConnectionInterfaceRenaming))
+#define TP_IS_SVC_CONNECTION_INTERFACE_RENAMING(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_RENAMING))
+#define TP_SVC_CONNECTION_INTERFACE_RENAMING_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_RENAMING, TpSvcConnectionInterfaceRenamingClass))
+
+
+typedef void (*tp_svc_connection_interface_renaming_request_rename_impl) (TpSvcConnectionInterfaceRenaming *self,
+    const gchar *in_Identifier,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_renaming_implement_request_rename (TpSvcConnectionInterfaceRenamingClass *klass, tp_svc_connection_interface_renaming_request_rename_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_renaming_return_from_request_rename (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_renaming_return_from_request_rename (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_renaming_emit_renamed (gpointer instance,
+    guint arg_Original,
+    guint arg_New);
+
 typedef struct _TpSvcConnectionInterfaceRequests TpSvcConnectionInterfaceRequests;
 
 typedef struct _TpSvcConnectionInterfaceRequestsClass TpSvcConnectionInterfaceRequestsClass;
@@ -1507,6 +1539,41 @@ GType tp_svc_connection_interface_service_point_get_type (void);
 void tp_svc_connection_interface_service_point_emit_service_points_changed (gpointer instance,
     const GPtrArray *arg_Service_Points);
 
+typedef struct _TpSvcConnectionInterfaceSidecars1 TpSvcConnectionInterfaceSidecars1;
+
+typedef struct _TpSvcConnectionInterfaceSidecars1Class TpSvcConnectionInterfaceSidecars1Class;
+
+GType tp_svc_connection_interface_sidecars1_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_SIDECARS1 \
+  (tp_svc_connection_interface_sidecars1_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_SIDECARS1(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_SIDECARS1, TpSvcConnectionInterfaceSidecars1))
+#define TP_IS_SVC_CONNECTION_INTERFACE_SIDECARS1(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_SIDECARS1))
+#define TP_SVC_CONNECTION_INTERFACE_SIDECARS1_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_SIDECARS1, TpSvcConnectionInterfaceSidecars1Class))
+
+
+typedef void (*tp_svc_connection_interface_sidecars1_ensure_sidecar_impl) (TpSvcConnectionInterfaceSidecars1 *self,
+    const gchar *in_Main_Interface,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_sidecars1_implement_ensure_sidecar (TpSvcConnectionInterfaceSidecars1Class *klass, tp_svc_connection_interface_sidecars1_ensure_sidecar_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_sidecars1_return_from_ensure_sidecar (DBusGMethodInvocation *context,
+    const gchar *out_Path,
+    GHashTable *out_Properties);
+static inline void
+tp_svc_connection_interface_sidecars1_return_from_ensure_sidecar (DBusGMethodInvocation *context,
+    const gchar *out_Path,
+    GHashTable *out_Properties)
+{
+  dbus_g_method_return (context,
+      out_Path,
+      out_Properties);
+}
+
+
 typedef struct _TpSvcConnectionInterfaceSimplePresence TpSvcConnectionInterfaceSimplePresence;
 
 typedef struct _TpSvcConnectionInterfaceSimplePresenceClass TpSvcConnectionInterfaceSimplePresenceClass;
