@@ -1,5 +1,8 @@
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
+#include <telepathy-glib/dbus.h>
+#include <telepathy-glib/dbus-properties-mixin.h>
+
 
 G_BEGIN_DECLS
 
