@@ -18,11 +18,16 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#if defined (TP_DISABLE_SINGLE_INCLUDE) && !defined (_TP_IN_META_HEADER) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib.h> and <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
+#endif
+
 #ifndef __TP_AUTOMATIC_CLIENT_FACTORY_H__
 #define __TP_AUTOMATIC_CLIENT_FACTORY_H__
 
 #include <telepathy-glib/call-channel.h>
 #include <telepathy-glib/dbus-tube-channel.h>
+#include <telepathy-glib/defs.h>
 #include <telepathy-glib/file-transfer-channel.h>
 #include <telepathy-glib/simple-client-factory.h>
 #include <telepathy-glib/stream-tube-channel.h>
@@ -43,6 +48,7 @@ struct _TpAutomaticClientFactory {
     TpSimpleClientFactory parent;
 };
 
+_TP_AVAILABLE_IN_0_16
 GType tp_automatic_client_factory_get_type (void);
 
 #define TP_TYPE_AUTOMATIC_CLIENT_FACTORY \
@@ -61,6 +67,7 @@ GType tp_automatic_client_factory_get_type (void);
   (G_TYPE_INSTANCE_GET_CLASS ((obj), TP_TYPE_AUTOMATIC_CLIENT_FACTORY, \
                               TpAutomaticClientFactoryClass))
 
+_TP_AVAILABLE_IN_0_16
 TpAutomaticClientFactory *tp_automatic_client_factory_new (TpDBusDaemon *dbus);
 
 G_END_DECLS
