@@ -1,3 +1,7 @@
+#if defined (TP_DISABLE_SINGLE_INCLUDE) && !defined (_TP_IN_META_HEADER) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
+#endif
+
 #ifndef __TP_META_SVC_ACCOUNT_H__
 #define __TP_META_SVC_ACCOUNT_H__
 
